@@ -395,8 +395,8 @@ class RundeckJobs(object):
 
         config_dir_location = f'/tmp/{fqdn}.{deployment_environment}.build'
         rmdir(config_dir_location)
-        if os.path.exists(f"{terraform_code_dir}/.terraform.lock.hcl"):
-            os.remove(f"{terraform_code_dir}/.terraform.lock.hcl")
+        # if os.path.exists(f"{terraform_code_dir}/.terraform.lock.hcl"):
+        #     os.remove(f"{terraform_code_dir}/.terraform.lock.hcl")
 
         backend_config_file_location = f"/tmp/{fqdn}.{deployment_environment}.build.backend.tfvars"
         backend_config_file_content = f'''conn_str = "{pg_backend_conn_str}"'''
@@ -485,8 +485,8 @@ class RundeckJobs(object):
 
         config_dir_location = f'/tmp/{fqdn}'
         rmdir(config_dir_location)
-        if os.path.exists(f"{terraform_code_dir}/.terraform.lock.hcl"):
-            os.remove(f"{terraform_code_dir}/.terraform.lock.hcl")
+        # if os.path.exists(f"{terraform_code_dir}/.terraform.lock.hcl"):
+        #     os.remove(f"{terraform_code_dir}/.terraform.lock.hcl")
 
         backend_config_file_location = f"/tmp/{fqdn}.backend.tfvars"
         backend_config_file_content = '''
