@@ -123,6 +123,8 @@ def nextjs_build(
         organization: str = os.environ.get('RD_OPTION_ORGANIZATION'),
         deployment_action: str = os.environ.get(
             'RD_OPTION_DEPLOYMENT_ACTION'),
+        deployment_environment: str = os.environ.get(
+            'RD_OPTION_DEPLOYMENT_ENVIRONMENT'),
         git_domain: str = os.environ.get('RD_OPTION_GIT_DOMAIN'),
         git_reponame: str = os.environ.get('RD_OPTION_GIT_REPONAME'),
         git_branch: str = os.environ.get('RD_OPTION_GIT_BRANCH'),
@@ -136,7 +138,8 @@ def nextjs_build(
 ):
     rundeck_jobs = RundeckJobs()
     rundeck_jobs.nextjs_build(pg_user, pg_password, pg_ip, pg_port, pg_db, fqdn, organization, deployment_action,
-                              git_domain, git_reponame, git_branch, workspace_name, app_code_dir, vault_login_username,
+                              deployment_environment, git_domain, git_reponame, git_branch, workspace_name,
+                              app_code_dir, vault_login_username,
                               vault_login_password, terraform_code_dir)
 
 
@@ -163,9 +166,9 @@ def nextjs_deploy(
 
 ):
     rundeck_jobs = RundeckJobs()
-    rundeck_jobs.nextjs_deploy(fqdn, git_branch, datacenter, organization, auto_apply, execution_mode,
-                               deployment_environment, deployment_action, vault_login_username,
-                               vault_login_password, jira_issue_key, terraform_cloud_token, terraform_code_dir)
+    rundeck_jobs.nextjs_deploy(fqdn, git_branch, datacenter, organization, execution_mode, deployment_environment,
+                               deployment_action, vault_login_username, vault_login_password, jira_issue_key,
+                               terraform_cloud_token, terraform_code_dir)
 
 
 if __name__ == "__main__":
